<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              AffiliateCashCode.com
 * @since             1.0.3
 * @package           Author_Category_Hider
 *
 * @wordpress-plugin
 * Plugin Name:       Author Category Hider
 * Plugin URI:        AffiliateCashCode.com
 * Description:       Hide the Author and Category sections from your blog
 * Version:           1.0.3
 * Author:            AffiliateCashCode
 * Author URI:        AffiliateCashCode.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       author-category-hider
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.3 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'AUTHOR_CATEGORY_HIDER_VERSION', '1.0.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-author-category-hider-activator.php
 */
function activate_author_category_hider() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-author-category-hider-activator.php';
	Author_Category_Hider_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-author-category-hider-deactivator.php
 */
function deactivate_author_category_hider() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-author-category-hider-deactivator.php';
	Author_Category_Hider_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_author_category_hider' );
register_deactivation_hook( __FILE__, 'deactivate_author_category_hider' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-author-category-hider.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.3
 */
function run_author_category_hider() {

	$plugin = new Author_Category_Hider();
	$plugin->run();

}
run_author_category_hider();
